LocalTranslationLoader class

Inheritance

Constructors

LocalTranslationLoader({String basePath = "assets/flutter_i18n", bool useCountryCode = false, bool useScriptCode = false, Locale? forcedLocale, List<BaseDecodeStrategy>? decodeStrategies})

Properties

assetBundle ↔ AssetBundle
getter/setter pairinherited
basePath → String
finalinherited
decodeStrategies ← List<BaseDecodeStrategy>?
no getterinherited
fallbackFile → String?
finalinherited
forcedLocale ← Locale?
Used to force the locale to load
no getterinherited
hashCode → int
The hash code for this object.
no setterinherited
locale ↔ Locale?
Currently locale used by the library
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
separator → String
finalinherited
useCountryCode → bool
finalinherited
useScriptCode → bool
finalinherited

Methods

composeFileName() → String
Compose the file name using the format languageCode_countryCode
inherited
findDeviceLocale() → Future<Locale>
Return the device current locale
inherited
load() → Future<Map>
Return the translation Map
inherited
loadFile(String fileName) → Future<Map>
Load the fileName using one of the strategies provided
inherited
loadString(String fileName, String extension) → Future<String>
Load the file using the File class
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited