TranslationLoader class abstract

Contains the common loading logic

Implementers

Constructors

TranslationLoader()

Properties

forcedLocale ← Locale?
Used to force the locale to load
no getter
hashCode → int
The hash code for this object.
no setterinherited
locale ↔ Locale?
Currently locale used by the library
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

findDeviceLocale() → Future<Locale>
Return the device current locale
load() → Future<Map>
Load method to implement
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited